import{_ as k}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Cz_guU--.js";import{A as h}from"./constants-HFTeRK_q.js";import{e as v,b as w,ak as A,l as o,f as B,v as i,n as m,j as p,w as t,p as e,am as I,b7 as _,B as x,q as a,t as c,k as C,b8 as N,ag as T,g as u,aO as D}from"./jwt-decode.esm-D4VPbsXq.js";import{u as E}from"./workspaceStore-B3Wo-cgd.js";import{C as S}from"./index-DSorSA9E.js";import"./logo-BiWG9_W5.js";import"./Logo-gbE1_hN1.js";import"./userStore-i0gLq6Lw.js";import"./runnerData-veWy0GOn.js";import"./url-DrKewZ5y.js";import"./colorHelpers-CSEqB2v6.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},l=new j().stack;l&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[l]="74fb7a8e-a0fc-489a-82c2-c93c0f6aeab3",r._sentryDebugIdIdentifier="sentry-dbid-74fb7a8e-a0fc-489a-82c2-c93c0f6aeab3")}catch{}})();const R={class:"inner-content"},V={class:"card-content"},H=v({__name:"Error",setup(r){const l=A(),g=T(),f=E(),b=w(()=>f.state.workspace?.name??f.state.workspace?.brandName),n=w(()=>{const{status:d}=l.params;switch(d){case"404":return{status:d,title:o.translate("i18n_page_not_found"),message:o.translate("i18n_page_not_found_message"),showAd:!1};case"403":return{status:d,title:o.translate("i18n_access_denied"),message:o.translate("i18n_access_denied_message"),action:"Go back to home",showAd:!0};default:return{status:"500",title:o.translate("i18n_internal_error"),message:o.translate("i18n_internal_error_message"),showAd:!1}}}),y=()=>{g.push({name:"playerHome"})};return(d,s)=>(u(),B("div",R,[i(e(I),null,{default:t(()=>[a(c(n.value.title),1)]),_:1}),i(e(_),{class:"message"},{default:t(()=>[a(c(n.value.message),1)]),_:1}),n.value.action?(u(),m(e(x),{key:0,type:"link",onClick:y},{default:t(()=>[a(c(n.value.action),1)]),_:1})):p("",!0),n.value.showAd?(u(),m(e(S),{key:1,bordered:!1,class:"card"},{default:t(()=>[C("div",V,[i(k,{style:{"margin-bottom":"10px"}}),i(e(_),null,{default:t(()=>[a("This page is part of "+c(b.value?`the ${b.value}`:"a")+" workflow, built with Abstra.",1)]),_:1}),e(f).state.workspace?(u(),m(e(_),{key:0},{default:t(()=>[s[1]||(s[1]=a("Automate your own processes by getting started ",-1)),i(e(N),{href:e(h).HOMEPAGE},{default:t(()=>[...s[0]||(s[0]=[a("here",-1)])]),_:1},8,["href"]),s[2]||(s[2]=a(".",-1))]),_:1})):p("",!0)])]),_:1})):p("",!0)]))}}),j=D(H,[["__scopeId","data-v-522ad0d4"]]);export{j as default};
//# sourceMappingURL=Error-2H6T3hhd.js.map
