import{A as n}from"./index-B1Fh0yIs.js";import{e as a,b as o,f as r,j as c,K as f,v as l,p,g as d,aO as i}from"./jwt-decode.esm-D4VPbsXq.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="343b4429-7e1f-4c62-a097-2f2e6ca3449e",e._sentryDebugIdIdentifier="sentry-dbid-343b4429-7e1f-4c62-a097-2f2e6ca3449e")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(d(),r("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[l(p(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),v=i(u,[["__scopeId","data-v-58fdd395"]]);export{v as S};
//# sourceMappingURL=Steps-PpcmFFlx.js.map
