import{N as c}from"./Navbar-DanSovQE.js";import{e as d,ak as u,b as a,l,a6 as f,f as _,g as y,v as p,k as I,aO as b}from"./jwt-decode.esm-D4VPbsXq.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-DTaFDDPd.js";import"./constants-HFTeRK_q.js";import"./PhCaretDown.vue-C8EfGi10.js";import"./PhPencilSimple.vue-LHi4w4_d.js";import"./router-CV8sojYz.js";import"./ts.worker-CNbeM3u4.js";import"./organization-BjRmfFvL.js";import"./tables-BZ_dXKLf.js";import"./string-BKmvhOWC.js";import"./keyboard-ChdTI2ls.js";import"./os-kZdnc5m_.js";import"./projectStore-2jlcekJT.js";import"./project-BJfEX558.js";import"./organizationSwitcher-fnjPCzWx.js";import"./cascaderStore-DgcxftJJ.js";import"./folder-B7fnTqwi.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-BpcS_Ns8.js";import"./member-EPmilim6.js";import"./index-DvCEsEFD.js";import"./index-DSorSA9E.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-BjXAcyj2.js";import"./PhNotePencil.vue-5YJ9cjdD.js";import"./PhSignOut.vue-DMmHlleH.js";import"./index-B6viKMTe.js";import"./index-CSMicJgu.js";import"./PhPlus.vue-7i6-2sMF.js";import"./omniChatStore-BzexAjwu.js";import"./contracts.generated-TRJrKuiD.js";import"./runnerData-veWy0GOn.js";import"./url-DrKewZ5y.js";import"./colorHelpers-CSEqB2v6.js";import"./uuid-BtxcfO0S.js";import"./PhCopySimple.vue-HEAGkZIG.js";import"./PhSparkle.vue-CSqWXyPg.js";import"./index-Dardg25i.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="979710e7-c5e1-468f-9049-8ba2d07d4599",e._sentryDebugIdIdentifier="sentry-dbid-979710e7-c5e1-468f-9049-8ba2d07d4599")}catch{}})();const v={class:"console-layout"},g={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=f("RouterView");return y(),_("div",v,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),I("div",g,[p(r)])])}}}),io=b(w,[["__scopeId","data-v-62f8634d"]]);export{io as default};
//# sourceMappingURL=ConsoleLayout-CvuLjBV8.js.map
