import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-Cz_guU--.js";import{B as y}from"./BaseLayout-DlQaHMwQ.js";import{e as l,V as _,a3 as b,aO as u,aJ as v,aK as g,g as m,f as h,k as o,M as s,S as w,ag as S,n as k,w as n,ak as B,v as i,p as I}from"./jwt-decode.esm-D4VPbsXq.js";import{u as $}from"./editor-AV8Fesfo.js";import{A as L}from"./index-Dardg25i.js";import"./logo-BiWG9_W5.js";import"./Logo-gbE1_hN1.js";import"./ts.worker-CNbeM3u4.js";import"./workspaceStore-B3Wo-cgd.js";import"./userStore-i0gLq6Lw.js";import"./runnerData-veWy0GOn.js";import"./url-DrKewZ5y.js";import"./colorHelpers-CSEqB2v6.js";import"./useCodebaseEvents-D6UGhkf3.js";import"./contracts.generated-TRJrKuiD.js";import"./router-BalMtApg.js";import"./constants-HFTeRK_q.js";import"./linters-D7GiM46V.js";import"./asyncComputed-C8n8hd2A.js";import"./index-B6viKMTe.js";import"./index-CSMicJgu.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="8ac035b2-0086-46b8-be23-a064614a295c",e._sentryDebugIdIdentifier="sentry-dbid-8ac035b2-0086-46b8-be23-a064614a295c")}catch{}})();const x=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"var(--ac-brand-primary)"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),D={class:"v-spinner"};function K(e,r,a,c,d,p){return v((m(),h("div",D,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const P=u(x,[["render",K],["__scopeId","data-v-224007fd"]]),R={class:"content"},z=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),c=$();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){a.push({name:"error"});return}await c.createLogin(t).then(d),a.push({name:"editor"})}),(t,A)=>(m(),k(y,null,{navbar:n(()=>[i(I(L),{style:{padding:"5px 25px",border:"1px solid var(--ac-border-subtle)"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[o("div",R,[i(P)])]),_:1}))}}),re=u(z,[["__scopeId","data-v-c9eeae4b"]]);export{re as default};
//# sourceMappingURL=ProjectLogin-IbsVDLTw.js.map
