import{e as _,ag as p,ak as f,l as s,n as m,g as c,w as i,f as g,O as y,Z as v,v as k,p as n,k as w,t as I}from"./jwt-decode.esm-D4VPbsXq.js";import{u as T}from"./projectStore-2jlcekJT.js";import{A as D,T as S}from"./index-DSorSA9E.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="9a03e5ef-0c49-479e-873c-d18b3ecb643e",e._sentryDebugIdIdentifier="sentry-dbid-9a03e5ef-0c49-479e-873c-d18b3ecb643e")}catch{}})();const N=_({__name:"TablesTabs",setup(e){const a=p(),r=f(),u=String(r.name),b=T(),o=[{label:s.translate("i18n_tablestabs_tables_list"),value:"tables"},{label:s.translate("i18n_tablestabs_diagram_view"),value:"tables-diagram"},{label:s.translate("i18n_tablestabs_run_sql"),value:"sql"}],d=l=>{a.push({name:String(l),params:{projectId:b.projectId}})};return(l,h)=>(c(),m(n(S),{"active-key":n(u),options:o,"onUpdate:activeKey":d},{default:i(()=>[(c(),g(y,null,v(o,t=>k(n(D),{key:t.value,name:t.value},{tab:i(()=>[w("span",null,I(t.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{N as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang-BUsugu7K.js.map
