import{i as b}from"./metadata-CAy2HyEE.js";import{W as h}from"./Watermark-BGG-l2IL.js";import{F as w}from"./PhArrowSquareOut.vue-DRPqT8Ql.js";import{e as v,b as x,r as C,f,j as D,p as e,v as c,w as s,E as u,n as r,q as y,t as _,l as I,b7 as g,O as z,Z as F,ag as B,g as a,K as E,X as L,aO as N}from"./jwt-decode.esm-D4VPbsXq.js";import{u as O}from"./workspaceStore-B3Wo-cgd.js";import{C as S}from"./index-DSorSA9E.js";import{L as T}from"./LoadingOutlined-DOcPgHNw.js";import"./PhHouse.vue-C1OoYcOd.js";import"./PhMagnifyingGlass.vue-CUUFwjgC.js";import"./PhWebhooksLogo.vue-B-EffPnn.js";import"./constants-HFTeRK_q.js";import"./userStore-i0gLq6Lw.js";import"./runnerData-veWy0GOn.js";import"./url-DrKewZ5y.js";import"./colorHelpers-CSEqB2v6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="b36b1a50-63f4-4dc1-a05b-233247ef60a4",o._sentryDebugIdIdentifier="sentry-dbid-b36b1a50-63f4-4dc1-a05b-233247ef60a4")}catch{}})();const V={key:0,class:"home-container"},W=v({__name:"Home",setup(o){const n=B(),i=O(),d=x(()=>i.state.workspace?.sidebar.filter(p=>p.id!=="home")||[]),l=C(null),k=async(p,m)=>{l.value=m,await n.push({path:`/${p}`}),l.value=null};return(p,m)=>e(i).state.workspace?(a(),f("div",V,[c(e(u),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[d.value.length===0?(a(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(a(!0),f(z,{key:1},F(d.value,t=>(a(),r(e(S),{key:t.id,class:E(["form-card",{loading:l.value===t.id}]),"body-style":{cursor:"pointer"},onClick:j=>k(t.path,t.id)},{default:s(()=>[c(e(u),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(a(),r(L(e(b)(t.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),c(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(_(t.name),1)]),_:2},1024),l.value!==t.id?(a(),r(e(w),{key:0,size:"20"})):(a(),r(e(T),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),c(h,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):D("",!0)}}),ee=N(W,[["__scopeId","data-v-132e66ff"]]);export{ee as default};
//# sourceMappingURL=Home-CBUVlwSb.js.map
