import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-Dmfhppxp.js";import{e as i,n,g as m,p as s}from"./jwt-decode.esm-D4VPbsXq.js";import{u as a}from"./projectStore-2jlcekJT.js";import"./router-CV8sojYz.js";import"./ts.worker-CNbeM3u4.js";import"./fetch-CWco3vRl.js";import"./tables-BZ_dXKLf.js";import"./string-BKmvhOWC.js";import"./SaveButton-DN6U8Ich.js";import"./ExclamationCircleOutlined-Z8MfEr68.js";import"./CrudView-DXIXF7NN.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-DdlPDoHq.js";import"./constants-HFTeRK_q.js";import"./url-DrKewZ5y.js";import"./PhDotsThreeVertical.vue-MlxVy5n2.js";import"./index-B6viKMTe.js";import"./asyncComputed-C8n8hd2A.js";import"./omniChatStore-BzexAjwu.js";import"./contracts.generated-TRJrKuiD.js";import"./runnerData-veWy0GOn.js";import"./colorHelpers-CSEqB2v6.js";import"./uuid-BtxcfO0S.js";import"./PhCopySimple.vue-HEAGkZIG.js";import"./PhPencil.vue-CEr_AydG.js";import"./useCodebaseEvents-D6UGhkf3.js";import"./index-Ie9yuaFA.js";import"./project-BJfEX558.js";import"./organizationSwitcher-fnjPCzWx.js";import"./organization-BjRmfFvL.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="2822d1a7-182a-4b38-ad25-bfe09a5655c7",o._sentryDebugIdIdentifier="sentry-dbid-2822d1a7-182a-4b38-ad25-bfe09a5655c7")}catch{}})();const J=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(d,c)=>(m(),n(p,{"env-var-repository":s(t),mode:"console"},null,8,["env-var-repository"]))}});export{J as default};
//# sourceMappingURL=EnvVars-DhCkG1Cu.js.map
