import{u as r}from"./userStore-i0gLq6Lw.js";import{W as n}from"./PlayerConfigProvider-B_hkqggs.js";import{u as c}from"./workspaceStore-B3Wo-cgd.js";import{e as i,H as f,n as m,j as d,p as o,w as u,v as p,a6 as l,g as w}from"./jwt-decode.esm-D4VPbsXq.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="2aaaf063-6609-4604-a631-c6983cb074c2",t._sentryDebugIdIdentifier="sentry-dbid-2aaaf063-6609-4604-a631-c6983cb074c2")}catch{}})();const C=i({__name:"App",setup(t){document.documentElement.dataset.theme="light";const a=r(),e=c();return e.actions.fetch(),f(()=>a.jwt,e.actions.fetch),(_,g)=>{const s=l("RouterView");return o(e).state.workspace?(w(),m(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[p(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):d("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-DqwkX1dE.js.map
