import{B as p}from"./BaseLayout-DlQaHMwQ.js";import{C as l}from"./ContentLayout-xWS4UThd.js";import{e as f,ak as _,b as i,H as g,a6 as b,n as r,g as s,w as d,v as y,j as w}from"./jwt-decode.esm-D4VPbsXq.js";import{_ as v}from"./BillingAlert.vue_vue_type_script_setup_true_lang-DSdBa-ma.js";import{u as z}from"./projectsStore-DX9X64aB.js";import"./router-CV8sojYz.js";import"./ts.worker-CNbeM3u4.js";import"./index-Ie9yuaFA.js";import"./member-EPmilim6.js";import"./organization-BjRmfFvL.js";import"./project-BJfEX558.js";import"./tables-BZ_dXKLf.js";import"./string-BKmvhOWC.js";import"./folder-B7fnTqwi.js";import"./ant-design-CYi4UYdw.js";import"./cascaderStore-DgcxftJJ.js";import"./organizationSwitcher-fnjPCzWx.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="728740cd-5548-496f-85de-4b1f1276e148",t._sentryDebugIdIdentifier="sentry-dbid-728740cd-5548-496f-85de-4b1f1276e148")}catch{}})();const $=f({__name:"Organization",setup(t){const e=_(),o=z(),n=i(()=>e.params.organizationId);g(n,a=>{a&&o.fetchedState?.organization?.id!==a&&o.fetchState(a)},{immediate:!0});const u=i(()=>o.fetchedState?.organization),m=i(()=>u.value?.billingMetadata);return(a,h)=>{const c=b("RouterView");return s(),r(p,null,{content:d(()=>[y(l,null,{default:d(()=>[m.value?(s(),r(v,{key:0,"billing-metadata":m.value,"organization-id":n.value},null,8,["billing-metadata","organization-id"])):w("",!0),(s(),r(c,{key:n.value}))]),_:1})]),_:1})}}});export{$ as default};
//# sourceMappingURL=Organization-Ti70fNfh.js.map
