import{_ as d,d as o}from"./NewEditor-Dr2_WDd_.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9bbf833c-9b5e-4cbe-b362-6265e7750c7d",e._sentryDebugIdIdentifier="sentry-dbid-9bbf833c-9b5e-4cbe-b362-6265e7750c7d")}catch{}})();var a=d((e,n)=>{let t;return n==="sandbox"&&(t=o("#i"+e)),(n==="sandbox"?o(t.nodes()[0].contentDocument.body):o("body")).select(`[id="${e}"]`)},"getDiagramElement");export{a as g};
//# sourceMappingURL=chunk-55IACEB6-2nYkaQtw.js.map
