import{_ as d}from"./Login.vue_vue_type_script_setup_true_lang-DTMN2WaT.js";import{e as p,f as i,v as u,p as n,ag as m,ak as l,g as f,aO as _}from"./jwt-decode.esm-D4VPbsXq.js";import{u as g}from"./workspaceStore-B3Wo-cgd.js";import"./OTPInput-BbZeOu9k.js";import"./Logo-gbE1_hN1.js";import"./string-BKmvhOWC.js";import"./CircularLoading-C93srCTe.js";import"./index-Ie9yuaFA.js";import"./userStore-i0gLq6Lw.js";import"./runnerData-veWy0GOn.js";import"./url-DrKewZ5y.js";import"./colorHelpers-CSEqB2v6.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8c64d5a6-d7c0-454e-997d-833978d01244",e._sentryDebugIdIdentifier="sentry-dbid-8c64d5a6-d7c0-454e-997d-833978d01244")}catch{}})();const y={class:"runner"},b=p({__name:"Login",setup(e){const o=m(),r=l(),t=g(),c=async()=>{const{redirect:a,...s}=r.query;if(a){await o.push({path:a,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>(f(),i("div",y,[u(d,{"logo-url":n(t).state.workspace?.logoUrl??void 0,"brand-name":n(t).state.workspace?.brandName,locale:n(t).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),R=_(b,[["__scopeId","data-v-12c690e1"]]);export{R as default};
//# sourceMappingURL=Login-Bg1Zsul2.js.map
