import{P as g}from"./PlayerNavbar-DScqdDFZ.js";import{e as _,ak as i,r as h,b as k,f as b,n as y,j as v,k as w,p as n,v as L,a6 as C,ag as I,g as c,aO as N}from"./jwt-decode.esm-D4VPbsXq.js";import{u as V}from"./workspaceStore-B3Wo-cgd.js";import"./userStore-i0gLq6Lw.js";import"./metadata-CAy2HyEE.js";import"./PhHouse.vue-C1OoYcOd.js";import"./PhMagnifyingGlass.vue-CUUFwjgC.js";import"./PhWebhooksLogo.vue-B-EffPnn.js";import"./LoadingOutlined-DOcPgHNw.js";import"./PhSignOut.vue-DMmHlleH.js";import"./index-CSMicJgu.js";import"./runnerData-veWy0GOn.js";import"./url-DrKewZ5y.js";import"./colorHelpers-CSEqB2v6.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="9f2edcda-4e0e-4c4d-b058-9007ab21dcd5",o._sentryDebugIdIdentifier="sentry-dbid-9f2edcda-4e0e-4c4d-b058-9007ab21dcd5")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(o){const e=I(),t=V(),d=i().path,a=h(null),p=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},u=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=k(()=>!!i().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return c(),b("div",B,[n(t).state.workspace?(c(),y(g,{key:0,"current-path":n(d),"hide-login":m.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:p,onLoginClick:l,onLogoutClick:u},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(f)])])}}}),H=N(R,[["__scopeId","data-v-f095bece"]]);export{H as default};
//# sourceMappingURL=Main-C876nrjf.js.map
